@@ -4,7 +4,8 @@ clustersegments <- function (x,P,bp,vh=TRUE){
   rupt       = matrix(ncol=2,nrow=K)
   rupt[,2]   = which(bp==1)
   rupt[,1]   = c(1,rupt[(2:K-1),2]+1)
-  phi        = EMalgo(x,rupt,P,vh)
+  phi0       = EMinit(x,rupt,P,vh)
+  phi        = EMalgo(x,phi0,rupt,P,vh)
   logdensity = t( apply(rupt,1,FUN=function(y) logdens(x[ y[1]:y[2] ] ,P,phi)))
   tau        = Estep(logdensity,phi)
   pop        = apply(tau,1,which.max)
