@@ -3,6 +3,10 @@ using namespace std;
 
 #include "logdens.h"
 
+#ifndef M_PI
+#define M_PI 3.141592653589793238462643383279502884197169399375
+#endif 
+
 namespace segclust {
 
 gsl_matrix *
